@@ -1,27 +1,27 @@
 /*
-mediastreamer2 library - modular sound and video processing and streaming
-Copyright (C) 2006  Simon MORLAT (simon.morlat@linphone.org)
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of mediastreamer2.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 #ifndef mscommon_h
 #define mscommon_h
 
 #include <bctoolbox/port.h>
 #include <bctoolbox/list.h>
-#include <ortp/logging.h>
+#include <bctoolbox/logging.h>
 #include <ortp/port.h>
 #include <ortp/str_utils.h>
 #include <ortp/payloadtype.h>
@@ -86,15 +86,76 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #elif defined(WINAPI_PARTITION_PHONE_APP) && WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_PHONE_APP)
 #define MS2_WINDOWS_PHONE 1
 #elif defined(WINAPI_PARTITION_APP) && WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_APP)
-#define MS2_WINDOWS_UNIVERSAL 1
+#define MS2_WINDOWS_DESKTOP 1
 #endif
 #endif
+
+#ifdef ENABLE_MICROSOFT_STORE_APP
+_Check_return_ WINOLEAPI
+CoCreateInstanceFromApp(
+    _In_ REFCLSID Clsid,
+    _In_opt_ IUnknown* punkOuter,
+    _In_ DWORD dwClsCtx,
+    _In_opt_ PVOID reserved,
+    _In_ DWORD dwCount,
+    _Inout_updates_(dwCount) MULTI_QI* pResults
+    );
+#endif
+__inline _Check_return_ HRESULT CoCreateInstanceBT(
+    _In_     REFCLSID rclsid,
+    _In_opt_ LPUNKNOWN pUnkOuter,
+    _In_     DWORD dwClsContext,
+    _In_     REFIID riid,
+    _COM_Outptr_ _At_(*ppv, _Post_readable_size_(_Inexpressible_(varies))) LPVOID FAR* ppv)
+{
+#ifdef ENABLE_MICROSOFT_STORE_APP
+    MULTI_QI    OneQI;
+    HRESULT     hr;
+
+    OneQI.pItf = NULL;
+
+#ifdef __cplusplus
+    OneQI.pIID = &riid;
+#else
+    OneQI.pIID = riid;
+#endif
+
+    hr = CoCreateInstanceFromApp( rclsid, pUnkOuter, dwClsContext, NULL, 1, &OneQI );
+
+#ifdef _PREFAST_
+    if (SUCCEEDED(hr) && SUCCEEDED(OneQI.hr))
+	_Analysis_assume_(OneQI.pItf != NULL);
+    else
+	_Analysis_assume_(OneQI.pItf == NULL);
+#endif
+
+    *ppv = OneQI.pItf;
+    return FAILED(hr) ? hr : OneQI.hr;
+#else
+	return CoCreateInstance(rclsid, pUnkOuter, dwClsContext, riid, ppv );
+#endif //ENABLE_MICROSOFT_STORE_APP
+}
+
+__inline _Check_return_ HRESULT CoCreateInstanceExBT(
+    _In_ REFCLSID                      Clsid,
+    _In_opt_ IUnknown     *            punkOuter,
+    _In_ DWORD                         dwClsCtx,
+    _In_opt_ COSERVERINFO *            pServerInfo,
+    _In_ DWORD                         dwCount,
+    _Inout_updates_(dwCount) MULTI_QI *pResults )
+{
+#ifdef ENABLE_MICROSOFT_STORE_APP
+    return CoCreateInstanceFromApp(Clsid, punkOuter, dwClsCtx, pServerInfo, dwCount, pResults);
+#else
+	return CoCreateInstanceEx(Clsid, punkOuter, dwClsCtx, pServerInfo, dwCount, pResults);
+#endif //ENABLE_MICROSOFT_STORE_APP
+}
 #endif
 
 #if defined(_MSC_VER)
 #ifdef MS2_STATIC
 #define MS2_PUBLIC
-#define MS2_VAR_PUBLIC
+#define MS2_VAR_PUBLIC extern
 #else
 #ifdef MS2_EXPORTS
 #define MS2_PUBLIC	__declspec(dllexport)
@@ -120,17 +181,17 @@ static MS2_INLINE void ms_debug(const char *fmt,...)
 {
   va_list args;
   va_start (args, fmt);
-  ortp_logv(ORTP_LOG_DOMAIN, ORTP_DEBUG, fmt, args);
+  bctbx_logv(BCTBX_LOG_DOMAIN, BCTBX_LOG_DEBUG, fmt, args);
   va_end (args);
 }
 #else
 #define ms_debug(fmt, ...)
 #endif
 
-#define ms_message	ortp_message
-#define ms_warning	ortp_warning
-#define ms_error	ortp_error
-#define ms_fatal	ortp_fatal
+#define ms_message	bctbx_message
+#define ms_warning	bctbx_warning
+#define ms_error	bctbx_error
+#define ms_fatal	bctbx_fatal
 
 #define ms_return_val_if_fail(_expr_,_ret_)\
 	if (!(_expr_)) { ms_fatal("assert "#_expr_ "failed"); return (_ret_);}
@@ -575,9 +636,17 @@ MS2_PUBLIC char *ms_load_path_content(const char *path, size_t *nbytes);
 #    define _(String) (String)
 #  endif // ENABLE_NLS
 #define N_(String) (String)
+
+/*
+ * Used by audio encoders in case no default standardized maxptime defined.
+ */
+#ifndef MS_DEFAULT_MAX_PTIME
+	#define MS_DEFAULT_MAX_PTIME 140
+#endif
+
 #endif // MS2_INTERNAL
 
-#ifdef ANDROID
+#ifdef __ANDROID__
 #include "mediastreamer2/msjava.h"
 #endif
 #endif
